@@ -1,6 +1,6 @@
 package OpenDNS::MyIP;
 # ABSTRACT: Get your public IP address
-$OpenDNS::MyIP::VERSION = '1.152330';
+$OpenDNS::MyIP::VERSION = '1.152350';
 use 5.006;
 use strict;
 use warnings;
@@ -47,7 +47,7 @@ OpenDNS::MyIP - Get your public IP address
 
 =head1 VERSION
 
-version 1.152330
+version 1.152350
 
 =head1 SYNOPSIS
 
@@ -63,15 +63,15 @@ Return public IP address
 
 =head1 SEE ALSO
 
-https://metacpan.org/pod/WWW::IP
+L<https://metacpan.org/pod/WWW::IP>
 
-https://metacpan.org/pod/WWW::curlmyip
+L<https://metacpan.org/pod/WWW::curlmyip>
 
-https://metacpan.org/pod/WWW::ipinfo
+L<https://metacpan.org/pod/WWW::ipinfo>
 
-https://metacpan.org/pod/WWW::hmaip
+L<https://metacpan.org/pod/WWW::hmaip>
 
-https://metacpan.org/pod/WWW::PerlTricksIP
+L<https://metacpan.org/pod/WWW::PerlTricksIP>
 
 =head1 AUTHOR
 
